@@ -2,6 +2,6 @@ from .application import application
 from .commands import ExtractCommand
 
 if __name__ == "__main__":
-    application.add(ExtractCommand())
-    application.set_default_command("extract", is_single_command=True)
+    extract = ExtractCommand()
+    application.add(extract.default())
     application.run()
